/*
 * Description
 *		Contains function needed to perform String value manipulation
 * Author
 *		SNT Development Team, 2005	
 *		First created at 2002, PKY.
 * Function Declaration:
 *		function trimleft( String strString ) : String
 *		function trimright( String strString ) : String
 *		function trim( String strString ) : String
 *		function trimTextField( Object objTextField ) : void
 *		function isMember( String pValue, TextList pValueList, Char pValueListSeperator ) : Boolean
 *		function appendToList( String, pValue, TextList pValueList, String pListSeperator, String pAllowRepeating ) : TextList
 *		function removeFromList( String pValue, TextList pValueList, Char pValueListSeperator ) : TextList
 *		function removeFirstFoundFromList( String pValue, TextList pValueList, Char pValueListSeperator ) : TextList
 * 		function padLeft( String pValue, Int maxLength, Char charToPad ) : String
 *		function improvedBubbleSort( arrArrSource, objTextField, vSeperator ) : arrDestination
 * Version
 *		Version 1.1
 * Last Edited
 * 		30-04-2003 AM
 */


/* 	
 * 	@Usage : Trim the whitespace on the left hand side of the string value
 *	@Return : Trimed string
 *	@Param 
 *			strString : Any string value
 */
function trimleft(strString){
	var strValue = String(strString);
	var strResult = String('');
	var bolSpace = true;
	for (var i=0;i<strValue.length;i++){
		if (strValue.charAt(i) != ' '){
			bolSpace = false;
		}
		if (bolSpace == false){
			strResult = strResult + strValue.charAt(i);
		}
	}
	return strResult;
}

/* 	
 * 	@Usage : Trim the whitespace on the right hand side of the string value
 *	@Return : Trimed string
 *	@Param 
 *			strString : Any string value
 */
function trimright(strString){
	var strValue = String(strString);
	var strResult = String('');
	var bolSpace = true;
	for (var i=(strValue.length-1);i>-1;i--){
		if (strValue.charAt(i) != ' '){
			bolSpace = false;
		}
		if (bolSpace == false){
			strResult = strValue.charAt(i) + strResult;
		}
	}
	return strResult;
}

/* 	
 * 	@Usage : Trim the whitespace on the both side of the string value
 *	@Return : Trimed string
 *	@Param 
 *			strString : Any string value
 */
function trim(strString){
	var strValue = String(strString);
	var strResult = String('');
	strResult = trimleft(strValue);
	strResult = trimright(strResult);
	return strResult;
}

/* 	
 * 	@Usage : Trim the text field.
 *	@Return : The actual value is the text field will be trim and updated.
 *	@Param 
 *			objTextField : Object, the text field to be trimed.
 */
function trimTextField( objTextField ){
	objTextField.value = trim( objTextField.value );
}

/* 	
 * 	@Usage : To check if a value exists in a text list.
 *	@Return : True if the given values is exist, false vice versa.
 *	@Param 
 *			pValue 			: The value to be test.
 *			pListValue		: The list value to be searched
 *			pListSeperator 	: The list seperator character, usually is a comma (,)
 */
function isMember( pValue, pListValue, pListSeperator ){
	vArray = pListValue.split( pListSeperator );
	vFound = false;
	for ( i=0; i<vArray.length && !vFound; i++ ){
		if ( vArray[ i ]==pValue ){
			vFound = true;
		}
	}
	return vFound;
}

function appendToList( pValue, pListValue, pListSeperator, pAllowRepeating ){
	if ( pListValue=="" ){
		return pValue
	}else{
		if ( pAllowRepeating.toUpperCase()=="YES" ){
			return pListValue+=pListSeperator+pValue;
		}else{
			vFound=false;
			vArrListValue = pListValue.split( pListSeperator );			
			for ( i=0; i<vArrListValue.length && ! vFound; i++ ){
				if ( vArrListValue[ i ]==pValue ){
					vFound=true;
				}
			}
			if ( vFound ){
				return pListValue;
			}else{
				return pListValue+=pListSeperator+pValue;
			}
		}
	}
}

/* 	
 * 	@Usage : Remove ALL pValue value from a given text list.
 *	@Return : The new text list with the value removed.
 *	@Param 
 *			pValue 			: The value to be test.
 *			pListValue		: The list value to be searched
 *			pListSeperator 	: The list seperator character, usually is a comma (,)
 */
function removeFromList( pValue, pListValue, pListSeperator ){
	vArray = pListValue.split( pListSeperator );
	vNewList = "";
	for ( i=0; i<vArray.length; i++ ){
		if ( vArray[ i ]!=pValue ){
			if ( vNewList=="" ){
				vNewList = vArray[ i ]
			}else{
				vNewList = vNewList + "," + vArray[ i ]
			}
		}
	}
	return vNewList;
}

/* 	
 * 	@Usage : Remove the first pValue from a given text list.
 *	@Return : The new text list with the value removed.
 *	@Param 
 *			pValue 			: The value to be test.
 *			pListValue		: The list value to be searched
 *			pListSeperator 	: The list seperator character, usually is a comma (,)
 */
function removeFirstFoundFromList( pValue, pListValue, pListSeperator ){
	vArray = pListValue.split( pListSeperator );
	vNewList = "";
	vFirstValueFound=false;
	for ( i=0; i<vArray.length; i++ ){
		if ( vArray[ i ]==pValue && vFirstValueFound==false ){
			vFirstValueFound=true;
		}else{
			if ( vNewList=="" ){
				vNewList = vArray[ i ]
			}else{
				vNewList = vNewList + "," + vArray[ i ]
			}
		}		
	}
	return vNewList;
}

/* 	
 * 	@Usage : Pad pCharToPad to the left side of the string until pMaxLength reached.
 *	@Return : The new string with padded char in front (left side)..
 *	@Param 
 *			pValue 			: The original value to be pad.
 *			pMaxLength	: The maximum length of the character to be pad;
 *			pCharToPad	: The character that used to do padding, MUST be one character only. Eg. '0'.
 */
function padLeft( pValue, pMaxLength, pCharToPad ){
	vLength = pValue.length;
	vLoopNeeded = pMaxLength-vLength;
	vValue = pValue;
	for (i=0; i<vLoopNeeded; i++ ){
		vValue=pCharToPad+vValue;
	}
	return vValue;
}

/* 	
 * 	@Usage : Pad pCharToPad to the right side of the string until pMaxLength reached.
 *	@Return : The new string with padded char in front (left side)..
 *	@Param 
 *			pValue 			: The original value to be pad.
 *			pMaxLength	: The maximum length of the character to be pad;
 *			pCharToPad	: The character that used to do padding, MUST be one character only. Eg. '0'.
 */
function padRight( pValue, pMaxLength, pCharToPad ){
	vLength = pValue.length;
	vLoopNeeded = pMaxLength-vLength;
	vValue = pValue;
	for (i=0; i<vLoopNeeded; i++ ){
		vValue+=pCharToPad;
	}
	return vValue;
}

function ReplaceSubstring( pString, strChar1, strChar2){
	var strString = pString;
	while (strString.indexOf(strChar1) > 0){
		strString = strString.replace(strChar1, strChar2);
	}
	return strString;
}

function escapeForQS ( pString ){
	var1 = ReplaceSubstring( pString, "+", "@@@" );
	var2 = ReplaceSubstring( var1, "&", "%%%" );
	var3 = ReplaceSubstring( var2, "\"", "$$$" );
	var4 = ReplaceSubstring( var3, "<", "???" );
	var5 = ReplaceSubstring( var4, ">", "###" );
	return var5
}

function unescapeForQS ( pString ){
	var1 = ReplaceSubstring( pString, "@@@", "+" );
	var2 = ReplaceSubstring( var1, "%%%", "&" );
	var3 = ReplaceSubstring( var2, "$$$", "\"" );
	var4 = ReplaceSubstring( var3, "???", "<" );
	var5 = ReplaceSubstring( var4, "###", ">" );
	return var5
}

function improvedBubbleSort( arrSource, objTextField, strSeperator, strSortOption ){
	var sorted=false;
	var pass=1;
	var vLength = arrSource.length;
	var arrSorted = arrSource;
	var temp="";
	if ( strSortOption=="" ){ strSortOption="ASC" }

	isString=false;
	for ( i=0; i<arrSource.length && ! isString; i++ ){
		isString=isNaN( arrSource[ i ] )
	}
	
	strSortTextOrNum = "TEXT"
	if ( ! isString ){
		strSortTextOrNum = "NUMBER"
	}

	while (( ! sorted ) && ( pass<vLength ) ){
		sorted = true;
		for ( i=0; i<vLength-pass; i++ ){
			if (strSortOption=="ASC" ){
				if ( strSortTextOrNum=="NUMBER" ){
					if ( parseInt( arrSorted[ i ] ) > parseInt( arrSorted[ i+1 ] ) ){
						temp = arrSorted[ i ];
						arrSorted[ i ] = arrSorted[ i+1 ]
						arrSorted[ i + 1] = temp;
						sorted=false;
					}
				}else{
					if (arrSorted[ i ] > arrSorted[ i+1 ]){
						temp = arrSorted[ i ];
						arrSorted[ i ] = arrSorted[ i+1 ]
						arrSorted[ i + 1] = temp;
						sorted=false;
					}
				}
			}
			if (strSortOption=="DES" ){
				if ( strSortTextOrNum=="NUMBER" ){
					if ( parseInt( arrSorted[ i ] ) < parseInt( arrSorted[ i+1 ] ) ){
						temp = arrSorted[ i ];
						arrSorted[ i ] = arrSorted[ i+1 ]
						arrSorted[ i + 1] = temp;
						sorted=false;
					}
				}else{
					if (arrSorted[ i ] < arrSorted[ i+1 ]){
						temp = arrSorted[ i ];
						arrSorted[ i ] = arrSorted[ i+1 ]
						arrSorted[ i + 1] = temp;
						sorted=false;
					}
				}
			}
		}
		pass++;
	}

	if ( objTextField!="" ){
		for ( k=0; k<arrSorted.length; k++ ){
			if ( objTextField.value=="" ){			
				objTextField.value += arrSorted[ k ];
			}else{
				objTextField.value += strSeperator + arrSorted[ k ];
			}
		}
	}
	return arrSorted;
}

